@@ -464,7 +464,7 @@ def batch_profiling(fn):
 
 import fcntl, os, time
 import errno
-def openPortFile(filepath=os.environ.get('WHATAP_LOCK_FILE', '/var/lock/whatap-python.lock')):
+def openPortFile(filepath=os.environ.get('WHATAP_LOCK_FILE', '/tmp/whatap-python.lock')):
     f = None
     i=0
     while f == None and i < 100:
