@@ -53,7 +53,7 @@ class UdpSession(object):
         else:
             sock = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
             sock.setsockopt(socket.SOL_SOCKET, socket.SO_SNDBUF, PacketEnum.PACKET_SEND_BUFFER_SIZE)
-            sock.connect((PacketEnum.SERVER, PacketEnum.PORT))
+            sock.connect((PacketEnum.SERVER, int(conf.net_udp_port)))
             sock.settimeout(cls.read_timeout)
             if cls.s:
                 try:
